<?php

/**
 * The claim collections interface.
 */
interface AlbAuthClaimCollectionInterface {

  /**
   * Creates claim collection from the values array.
   *
   * @param array $data
   *   Claims name => value array.
   *
   * @return static
   */
  public static function fromArray(array $data);

  /**
   * Returns all claims.
   *
   * @return AlbAuthClaimInterface[]
   *   An array of claims, keyed by claim name.
   */
  public function getClaims();

  /**
   * Returns claim by name.
   *
   * @param string $name
   *   The claim name.
   *
   * @return AlbAuthClaimInterface|null
   *   The claim object or NULL.
   */
  public function getClaimByName($name);

  /**
   * Returns the claim value of default, if the claim does not exist.
   *
   * @param string $name
   *   The claim name.
   * @param mixed $default
   *   The default claim value to return if no such claim exists.
   *
   * @return mixed
   *   The claim value or default if there's no such claim.
   */
  public function getClaimValue($name, $default = NULL);

  /**
   * Checks whether there is at least one claim.
   *
   * @return bool
   *   TRUE is there is at least one claim.
   */
  public function hasData();

  /**
   * Converts collection object to an array.
   *
   * @return array
   *   An array of claims.
   */
  public function toArray();

  /**
   * Returns unique claims collections hash.
   *
   * This hash may be used to compare new claims collection with a previously
   * stored/applied one.
   *
   * @return string
   *   SHA-1 hash string.
   */
  public function hash();

}
