<?php

/**
 * Base class for ALB Auth tests providing some helper methods.
 */
abstract class AlbAuthUnitTestBase extends DrupalUnitTestCase {

  /**
   * Asserts array values count.
   *
   * @param int $count
   *   Expected array values count.
   * @param mixed $array
   *   The input array.
   */
  protected function assertCount($count, $array) {
    if (!is_int($count)) {
      throw new LogicException('count should be an integer');
    }

    if (!is_array($array)) {
      $this->error('Not an array');
    }

    $this->assertIdentical($count, count($array), "Array values count is identical to expected $count.");
  }

  /**
   * Asserts the object is instance of class or interface.
   *
   * @param string $class_name
   *   The class or interface name.
   * @param mixed $object
   *   The asserted object.
   *
   * @return bool
   *   The assertion result.
   */
  protected function assertInstanceOf($class_name, $object) {
    if (!(is_string($class_name) && (class_exists($class_name) || interface_exists($class_name)))) {
      throw new LogicException('Invalid class or interface name');
    }

    if (!is_object($object)) {
      return $this->error('Asserted value is not an object.');
    }

    return $this->assertTrue($object instanceof $class_name, "Object is instance of $class_name.");
  }

}
